Module registry

Module registry 

Download URL construction and extraction logic for each Docker tool.

Enums

ArtifactFormat
Format of the downloaded artifact.

Functions

artifact_format
Returns the artifact format for a given tool name.
download_url
Returns the download URL for the given tool name, version, and architecture.
tgz_inner_path
Returns the name of the binary inside the archive for tgz artifacts. For example, the docker tgz contains docker/docker.