Download URL construction and extraction logic for each Docker tool.
Enums
- Artifact
Format - Format of the downloaded artifact.
Functions
- artifact_
format - Returns the artifact format for a given tool name.
- download_
url - Returns the download URL for the given tool name, version, and architecture.
- tgz_
inner_ path - Returns the name of the binary inside the archive for tgz artifacts.
For example, the
dockertgz containsdocker/docker.